from enum import Enum


class Lang(Enum):
    AR = "lang_ar"
    BG = "lang_bg"
    CA = "lang_ca"
    CS = "lang_cs"
    DA = "lang_da"
    DE = "lang_de"
    EL = "lang_el"
    EN = "lang_en"
    ES = "lang_es"
    ET = "lang_et"
    FI = "lang_fi"
    FR = "lang_fr"
    HR = "lang_hr"
    HU = "lang_hu"
    ID = "lang_id"
    IS = "lang_is"
    IT = "lang_it"
    IW = "lang_iw"
    JA = "lang_ja"
    KO = "lang_ko"
    LT = "lang_lt"
    LV = "lang_lv"
    NL = "lang_nl"
    NO = "lang_no"
    PL = "lang_pl"
    PT = "lang_pt"
    RO = "lang_ro"
    RU = "lang_ru"
    SK = "lang_sk"
    SL = "lang_sl"
    SR = "lang_sr"
    SV = "lang_sv"
    TR = "lang_tr"
    ZH_CN = "lang_zh-CN"
    zh_TW = "lang_zh-TW"
